==> localnews-message-common-1.1.0-sources.jar: com/bxm/localnews/message/constant/AliMqMsgTagEnum.java <==
package com.bxm.localnews.message.constant;

import java.util.Optional;
import java.util.stream.Stream;

/**
 * Created by Arei on 2018/10/12.
 * 此类用于标识阿里云MQ的Messgae的tag所对应所属的topic及相应的生产者消费者
 * 所有使用的tag都要在这里注册，有新的topicType需要修改Enum+AliMQService
 *
 * @author arei
 */
public enum AliMqMsgTagEnum {
    /**
     * 短信tag
     */
    SMS("sms", "sms", "smsProducer"),
    /**
     * 推送单条消息tag
     */
    PUSH("push", "push", "pushProducer"),
    /**
     * 推送所有用户消息tag
     */
    PUSH_ALL("push", "push_all", "pushProducer"),
    /**
     * 推送批量用户消息
     */
    PUSH_GROUP("push", "push_group", "pushProducer");

    /**
     * aliMQ topic类型，用来帮助获取配置类中对应的topic
     */
    private String topicType;

    /**
     * aliMQ Messga中的tag，用来标识具体业务
     */
    private String tag;

    /**
     * aliMQ生产者ProducerBean类的具体实现类名（注册在SpringContext中具体组件名）
     */
    private String producerName;

    AliMqMsgTagEnum(String topicType, String tag, String producerName) {
        this.topicType = topicType;
        this.tag = tag;
        this.producerName = producerName;
    }

    /**
     * 判断tag是否已经注册在Enum中
     *
     * @param tag
     * @return
     */
    public static Optional<AliMqMsgTagEnum> getTagEnumByTag(String tag) {
        return Stream.of(AliMqMsgTagEnum.values()).filter(tagEnum -> tag.equals(tagEnum.getTag())).findAny();
    }

    /**
     * 获取tag对应的topicType来获取实际的topic值
     *
     * @param tag
     * @return
     */
    public static String getTopicTypeByTag(String tag) {
        Optional<AliMqMsgTagEnum> tagEnumOptional = getTagEnumByTag(tag);
        if (tagEnumOptional.isPresent()) {
            return tagEnumOptional.get().getTopicType();
        } else {
            return "";
        }
    }

    /**
     * 获取tag对应的生产者名来调用对应的实际生产者组件
     *
     * @param tag
     * @return
     */
    public static String getProducerNameByTag(String tag) {
        Optional<AliMqMsgTagEnum> tagEnumOptional = getTagEnumByTag(tag);
        if (tagEnumOptional.isPresent()) {
            return tagEnumOptional.get().getProducerName();
        } else {
            return "producer";
        }
    }

    public String getProducerName() {
        return producerName;
    }

    public String getTopicType() {
        return topicType;
    }

    public String getTag() {
        return tag;
    }
}

==> localnews-message-common-1.1.0-20181023.092117-2-sources.jar: com/bxm/localnews/message/constant/AliMqMsgTagEnum.java <==
package com.bxm.localnews.message.constant;

import java.util.Optional;
import java.util.stream.Stream;

/**
 * Created by Arei on 2018/10/12.
 * 此类用于标识阿里云MQ的Messgae的tag所对应所属的topic及相应的生产者消费者
 * 所有使用的tag都要在这里注册，
 *
 * @author arei
 */
// TODO: 2018/10/12 tag对应topic的方式有点蠢,有新的topicType需要修改Enum+AliMQService
public enum AliMqMsgTagEnum {
    /**
     * 短信tag
     */
    SMS("sms", "sms", "smsProducer"),
    /**
     * 推送单条消息tag
     */
    PUSH("push", "push", "pushProducer"),
    /**
     * 推送所有用户消息tag
     */
    PUSH_ALL("push", "push_all", "pushProducer");
    /**
     * aliMQ topic类型，用来帮助获取配置类中对应的topic
     */
    private String topicType;
    /**
     * aliMQ Messga中的tag，用来标识具体业务
     */
    private String tag;
    /**
     * aliMQ生产者ProducerBean类的具体实现类名（注册在SpringContext中具体组件名）
     */
    private String producerName;

    AliMqMsgTagEnum(String topicType, String tag, String producerName) {
        this.topicType = topicType;
        this.tag = tag;
        this.producerName = producerName;
    }

    public String getProducerName() {
        return producerName;
    }

    public String getTopicType() {
        return topicType;
    }

    public String getTag() {
        return tag;
    }

    /**
     * 判断tag是否已经注册在Enum中
     *
     * @param tag
     * @return
     */
    public static Optional<AliMqMsgTagEnum> getTagEnumByTag(String tag) {
        Optional<AliMqMsgTagEnum> tagEnumOptional = Stream.of(AliMqMsgTagEnum.values())
                .filter(tagEnum -> tag.equals(tagEnum.getTag())).findAny();
        return tagEnumOptional;
    }

    /**
     * 获取tag对应的topicType来获取实际的topic值
     *
     * @param tag
     * @return
     */
    public static String getTopicTypeByTag(String tag) {
        Optional<AliMqMsgTagEnum> tagEnumOptional = getTagEnumByTag(tag);
        if (tagEnumOptional.isPresent()) {
            return tagEnumOptional.get().getTopicType();
        } else {
            return "";
        }
    }

    /**
     * 获取tag对应的生产者名来调用对应的实际生产者组件
     *
     * @param tag
     * @return
     */
    public static String getProducerNameByTag(String tag) {
        Optional<AliMqMsgTagEnum> tagEnumOptional = getTagEnumByTag(tag);
        if (tagEnumOptional.isPresent()) {
            return tagEnumOptional.get().getProducerName();
        } else {
            return "producer";
        }
    }
}
